Function input
Source pub fn input(prompt: &str) -> Result<String, Error>
Does a readline from stdin and returns a trimmed string in a Result
Arguments
prompt - A string slice that is displayed as a prompt to the user
Examples
let name = oh::input("What's your name? : ").expect("Error at input.");
println!("Oh! So your name is {}!", name);